@@ -231,7 +231,11 @@ def get_dependencies(groups,all_extras=False):
 
 
 def get_buildreqs():
-    import pip._vendor.pytoml as toml
+    try:
+        import pip._vendor.pytoml as toml
+    except:
+        # pip>=20.1
+        import pip._vendor.toml as toml
     buildreqs = []
     if os.path.exists('pyproject.toml'):
         pp = toml.load(open('pyproject.toml'))
